@@ -7,7 +7,7 @@ popsizedist.plot.landscape <- function(Rland)
   {
     if (is.landscape(Rland))
       {
-        plot.table(table(populations(Rland)),
+        plot.table(table(landscape.populations(Rland)),
                    main="Frequency distribution of population sizes",
                    xlab=c("Population"),
                    ylab=c("Number of individuals"),
